<?php

/* system includes */
require('../../settings/settings.php');
require('../../systemincludes/alwaysinclude.php');
require('../../systemincludes/authenticate.php');
require('../../systemincludes/hshcheck.php');
if( $_POST['deletehash'] && !checkPWHashString($_POST['deletehash'],'createdatabase') ) {
	include('../../incontent/hashfailed.php');
	exit;
}
require('../../systemincludes/sqlfunctions.php');

/* template includes */
include('../../includes/headstart.php');

?>

<title>Creating database tables</title>

<?php include('../../includes/headend.php'); ?>

<h1>Creating database tables</h1>

<?php

/* navigation template includes */
function getPageNav() {
	include('../../includes/navstart.php');
	include('../../includes/navadmin.php');
	include('../../includes/navend.php');
}

if( $navfirst ) { getPageNav(); }
include('../../includes/contentstart.php');

/* checking for errors when adding to the database */
function printStatus( $oDel = false ) {
	if( sqlfunct_error() ) {
		print '<h3>SQL error:</h3><p>'.htmlspecialchars(sqlfunct_error())."</p>\n";
	} else {
		print '<p>Table '.($oDel?'deleted':'created').".</p>\n";
	}
}

/* checking if the database tables already exist */
/* markup and text can be customised, but note that the form will not work without the hidden input */
$dbworks = @sqlfunct_query( "SELECT * FROM movies");
if( !$_POST['recreate'] && !$_POST['deletehash'] && $dbworks ) {
	?>
	<h2>Create failed</h2>
	<p>Database tables already exist.</p>
	<?php
} elseif( $_POST['recreate'] && $dbworks ) {
	?>
	<h2>Recreate database tables</h2>
	<p>Database tables already exist. You will need to delete all tables in the database if you want to recreate them.
	You will lose all data currently stored in the database.
	If you are absolutely certain you want to do this, use the button below.
	You will not be warned again.</p>
	<form action="./" method="post">
		<fieldset>
			<legend>Recreate database tables</legend>
			<input type="submit" value="Erase database contents and create new tables"/><input type="hidden" name="deletehash" value="<?php print getPWHashString('createdatabase',true); ?>"/>
		</fieldset>
	</form>
	<?php
} else {

	/* creation is about to begin */
	if( $_POST['deletehash'] ) {
		/* deleting tables */
		print "<h2>Warning</h2>";
		print '<p>Reloading this page will cause the database content to be deleted again.</p>';
		$tablelist = Array('movies','actors','categories','studios','directors','moviecat','movieact');
		foreach( $tablelist as $onetable ) {
			print '<h2>Deleting table \''.$onetable.'\'</h2>';
			sqlfunct_query( "DROP TABLE ".$onetable );
			printStatus(true);
		}
	}

	/* creating tables */
	print '<h2>Creating table \'movies\'</h2>';
	sqlfunct_query( "CREATE TABLE movies ( name varchar(255) default NULL, shortname varchar(50) NOT NULL PRIMARY KEY, description text, cover varchar(255), thumb varchar(255), fullcover varchar(255), director varchar(50), studio varchar(50), year int(4) DEFAULT 0, status int(1) DEFAULT 0, rating1 int(1) DEFAULT 0, rating2 int(1) DEFAULT 0, rating3 int(1) DEFAULT 0, rating4 int(1) DEFAULT 0, rating5 int(1) DEFAULT 0, comments text, runtime time, certification varchar(50), mediatype varchar(50), region tinyint(1) DEFAULT 0, format varchar(50), colour varchar(50), audio varchar(50), boughtdate date )" );
	printStatus();

	print '<h2>Creating table \'actors\'</h2>';
	sqlfunct_query( "CREATE TABLE actors ( firstname varchar(255) default NULL, lastname varchar(255) default NULL, shortname varchar(50) NOT NULL PRIMARY KEY, nickname varchar(255) default NULL, birthyear int(4) DEFAULT 0, deathyear int(4) DEFAULT 0, gender tinyint(1) DEFAULT 0, picture varchar(255), thumb varchar(255), bigpicture varchar(255), gallery text, stats text, specialities text, rating1 int(1) DEFAULT 0, rating2 int(1) DEFAULT 0, rating3 int(1) DEFAULT 0, rating4 int(1) DEFAULT 0, rating5 int(1) DEFAULT 0, rating6 int(1) DEFAULT 0, rating7 int(1) DEFAULT 0, rating8 int(1) DEFAULT 0, rating9 int(1) DEFAULT 0, rating10 int(1) DEFAULT 0, rating11 int(1) DEFAULT 0, rating12 int(1) DEFAULT 0, rating13 int(1) DEFAULT 0, rating14 int(1) DEFAULT 0, rating15 int(1) DEFAULT 0, rating16 int(1) DEFAULT 0, comments text )" );
	printStatus();

	print '<h2>Creating table \'categories\'</h2>';
	sqlfunct_query( "CREATE TABLE categories ( name varchar(255) default NULL, shortname varchar(50) NOT NULL PRIMARY KEY, parent varchar(50) NOT NULL )" );
	printStatus();

	print '<h2>Creating table \'studios\'</h2>';
	sqlfunct_query( "CREATE TABLE studios ( name varchar(255) default NULL, shortname varchar(50) NOT NULL PRIMARY KEY, specialities text )" );
	printStatus();

	print '<h2>Creating table \'directors\'</h2>';
	sqlfunct_query( "CREATE TABLE directors ( name varchar(255) default NULL, shortname varchar(50) NOT NULL PRIMARY KEY, specialities text, gender tinyint(1) DEFAULT 0 )" );
	printStatus();

	print '<h2>Creating table \'moviecat\'</h2>';
	sqlfunct_query( "CREATE TABLE moviecat ( movie varchar(50) default NULL, category varchar(50) default NULL, unqid int(5) NOT NULL auto_increment PRIMARY KEY )" );
	printStatus();

	print '<h2>Creating table \'movieact\'</h2>';
	sqlfunct_query( "CREATE TABLE movieact ( movie varchar(50) default NULL, actor varchar(50) default NULL, partsplayed varchar(255), unqid int(5) NOT NULL auto_increment PRIMARY KEY )" );
	printStatus();
}

/* template includes */
include('../../includes/contentend.php');
if( !$navfirst ) { getPageNav(); }
include('../../includes/bodyend.php');

?>