<?php

/* system includes */
require('../../settings/settings.php');
require('../../systemincludes/alwaysinclude.php');
require('../../systemincludes/authenticate.php');

/* template includes */
include('../../includes/headstart.php');

?>

<title>Customising</title>

<?php include('../../includes/headend.php'); ?>

<h1>Customising</h1>

<?php

/* navigation template includes */
function getPageNav() {
	include('../../includes/navstart.php');
	include('../../includes/navadmin.php');
	include('../../includes/navend.php');
}

if( $navfirst ) { getPageNav(); }
include('../../includes/contentstart.php');

?>

<h2>Using included templates</h2>

<ol>
	<li>All pages (even this one) are set up to use the include files in the includes/ directory, which can be modified to suit your needs. In general, these are the ones that should be modified.</li>
	<li>Files are included in similar way to SSI, but use the PHP 'include' or 'require' functions instead of the SSI '#include virtual'.</li>
	<li>Template files are added using 'include', since failure to load them is not considered to be a fatal error (if the included file fails to load, then the main file will still be completed without the included file, and sent to the browser).</li>
	<li>System files are added using 'require', since failure to load them is a fatal error, and the script must immediately terminate to prevent security risks.</li>
	<li>Main scripts specify a small amount of their own markup, but only the basic structure of headings and paragraphs, not the actual file structure. In general, they should not need to be edited.</li>
</ol>

<p>Note that relative URLs in 'include' calls are relative to the script that the user requested, not the script that is actually making the call. So if the user requests 'foo.php', and that includes 'bar/baz.php', and that in turn includes 'baz/qux.php', then qux.php will be in the same directory as baz.php, <em>not</em> 'bar/bar/qux.php'.</p>

<p>It is possible to get around this using something like this (this example assumes the include file is only one
directory in from the 'root' of the web site - if it were two, then '/../' would need to be changed to '/../../' etc.):</p>

<pre>$urlprefix = realpath( dirname(__FILE__) . '/../' ) . '/';
include($urlprefix.'includes/headstart.php');</pre>

<h2>Directories</h2>

<dl>
	<dt>includes/</dt>
		<dd>Template files for customisation.</dd>
	<dt>incontent/</dt>
		<dd>Incomplete parts of scripts that are included by the main scripts, but are not templates.</dd>
	<dt>settings/</dt>
		<dd>System settings configuration files.</dd>
	<dt>systemincludes/</dt>
		<dd>Important library files for the system that contain no markup. Any modification to those files risks breaking the system.</dd>
	<dt>*/includes/</dt>
		<dd>Forms used to add or edit database entries.</dd>
	<dt>images/actor/normal/</dt>
		<dd>Recommended location for location of actor pictures.</dd>
	<dt>images/actor/thumb/</dt>
		<dd>Recommended location for location of actor picture thumbnails.</dd>
	<dt>images/actor/big/</dt>
		<dd>Recommended location for location of actor big pictures.</dd>
	<dt>images/movie/normal/</dt>
		<dd>Recommended location for location of movie cover pictures.</dd>
	<dt>images/movie/thumb/</dt>
		<dd>Recommended location for location of movie cover picture thumbnails.</dd>
	<dt>images/movie/big/</dt>
		<dd>Recommended location for location of movie cover big pictures.</dd>
	<dt>Other</dt>
		<dd>Other directories (including the root) contain the main script files called directly (or by URL rewriting) by the browser.</dd>
</dl>

<h2>Basic template files</h2>

<p>The following default template files are used for generic file structure:</p>

<ol>
	<li>includes/headstart.php</li>
	<li>PAGE TITLE</li>
	<li>includes/headend.php</li>
	<li>optional includes/headup.php</li>
	<li>PAGE HEADING</li>
	<li>CONTENT:<ol>
		<li>includes/contentstart.php</li>
		<li>MAIN PAGE CONTENT</li>
		<li>optional includes/actionadd.php</li>
		<li>optional includes/actionedit.php</li>
		<li>includes/contentend.php</li>
	</ol></li>
	<li>NAVIGATION:<ol>
		<li>includes/navstart.php</li>
		<li>optional includes/navmain.php</li>
		<li>optional includes/navmainpublic.php</li>
		<li>optional includes/navback.php</li>
		<li>optional includes/navadmin.php</li>
		<li>optional SPECIFIC NAVIGATION</li>
		<li>optional includes/navsearch.php</li>
		<li>optional includes/navwish.php</li>
		<li>includes/navend.php</li>
	</ol></li>
	<li>includes/bodyend.php</li>
</ol>

<p>If the $navfirst setting (in settings/settings.php) is set to true, the NAVIGATION branch will be put before the CONTENT branch.</p>

<h2>Navigation templates</h2>

<dl>
	<dt>includes/headup.php</dt>
		<dd>Used by */showentry.php.</dd>
	<dt>includes/navadmin.php</dt>
		<dd>Used by pages in admin/ except admin/index.php.</dd>
	<dt>includes/navback.php</dt>
		<dd>Used by */deleteentry.php */editentry.php actors/managemovies.php movies/manageactors.php and movies/managecategories.php.</dd>
	<dt>includes/navmain.php</dt>
		<dd>Used by all main pages except those in the admin section.</dd>
	<dt>includes/navmainpublic.php</dt>
		<dd>Used by incontent/authfailed.php, incontent/hashfailed.php, and logout/index.php.</dd>
	<dt>includes/navsearch.php</dt>
		<dd>Used by all pages except those in the admin section, and search/index.php.</dd>
	<dt>includes/navwish.php</dt>
		<dd>Used by all pages except those in the admin section.</dd>
	<dt>SPECIFIC NAVIGATION</dt>
		<dd>Navigation included in the page script itself, not in an include file. Used by admin/index.php.</dd>
</dl>

<h2>Other templates</h2>

<dl>
	<dt>includes/actionadd.php</dt>
		<dd>Used by actors/index.php, directors/index.php, categories/index.php, movies/index.php, studios/index.php.</dd>
	<dt>includes/actionedit.php</dt>
		<dd>Used by actors/showentry.php, directors/showentry.php, categories/showentry.php, movies/showentry.php, studios/showentry.php.</dd>
</dl>

<h2>Partial content included files</h2>

<dl>
	<dt>incontent/authfailed.php</dt>
		<dd>Displayed if the HTTP authentication fails.</dd>
	<dt>incontent/cookieauthfailed.php</dt>
		<dd>Displayed if the cookie authentication fails.</dd>
	<dt>incontent/dbnotready.php</dt>
		<dd>Displayed if the database is not available, or if it does not contain the required tables.</dd>
	<dt>incontent/hashfailed.php</dt>
		<dd>Displayed if the hash checking fails. This is used to prevent XSRF attacks.</dd>
	<dt>incontent/dbrecreatestart.txt</dt>
	<dt>incontent/dbrecreateend.txt</dt>
		<dd>Used as the new content for recreatedatabase.php.</dd>
	<dt>*/includes/editform.php</dt>
		<dd>Contains the form used when adding or editing entries. Used by */addentry.php and */editentry.php.</dd>
</dl>

<h2>Admininstration script files</h2>

<dl>
	<dt>admin/index.php</dt>
		<dd>The main administration page.</dd>
	<dt>admin/createdatabase/index.php</dt>
		<dd>(Re)creates empty tables in the database.</dd>
	<dt>admin/customise/index.php</dt>
		<dd>This file.</dd>
	<dt>admin/dbdump/index.php</dt>
		<dd>Rewrites recreatedatabase.php with the current contents of the database tables, for use as a backup.</dd>
	<dt>admin/recreatedatabase/index.php</dt>
		<dd>Contains the database backup, and uses it to fill the database tables.</dd>
</dl>

<h2>.htaccess files</h2>

<dl>
	<dt>.htaccess</dt>
		<dd>Blocks Web access to includes/ incontent/ settings/ systemincludes/ and */includes/.</dd>
		<dd>Provides URL rewriting for virtual directories.</dd>
	<dt>images/*/.htaccess</dt>
		<dd>Password protects pictures.</dd>
	<dt>styles/private/.htaccess</dt>
		<dd>Password protects private stylesheets.</dd>
	<dt>.htpassword</dt>
		<dd>Contains the hashed password used by */*/.htaccess files.</dd>
</dl>

<h2>Database tables</h2>

<p>Unique identifiers are used to build the virtual URLs, and to build database table relationships.</p>

<h3>movies</h3>

<table>
	<thead><tr><th>Column</th><th>Type</th><th>Notes</th></tr></thead>
	<tbody>
		<tr><td>name</td><td>Text max 255</td><td>The movie title</td></tr>
		<tr><td>shortname</td><td>Text max 50</td><td>A short name used as a unique identifier</td></tr>
		<tr><td>description</td><td>Text unlimited</td><td>Markup with description</td></tr>
		<tr><td>cover</td><td>Text max 255</td><td>Path to local cover picture</td></tr>
		<tr><td>thumb</td><td>Text max 255</td><td>Path to local cover picture thumbnail</td></tr>
		<tr><td>fullcover</td><td>Text max 255</td><td>Path to local large cover picture</td></tr>
		<tr><td>director</td><td>Text max 50</td><td>Unique identifier of the director</td></tr>
		<tr><td>studio</td><td>Text max 50</td><td>Unique identifier of the studio</td></tr>
		<tr><td>year</td><td>Integer max 9999</td><td>Year the film was made</td></tr>
		<tr><td>status</td><td>Integer max 9</td><td>1=wanted, 2=ordered, 3=bought</td></tr>
		<tr><td>rating1</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating2</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating3</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating4</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating5</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>comments</td><td>Text unlimited</td><td>Markup with comments</td></tr>
		<tr><td>runtime</td><td>Time</td><td>The run time of the movie</td></tr>
		<tr><td>certification</td><td>Text max 50</td><td>The movie certification (PG/R/etc.)</td></tr>
		<tr><td>mediatype</td><td>Text max 50</td><td>The medium (DVD/Video/MPEG/etc.)</td></tr>
		<tr><td>region</td><td>Integer max 9</td><td>The DVD region</td></tr>
		<tr><td>format</td><td>Text max 50</td><td>TV format the movie is made for (PAL/NTSC+widescreen/SECAM/etc.)</td></tr>
		<tr><td>colour</td><td>Text max 50</td><td>The movie colour (colour/black and white/anaglyph/etc.)</td></tr>
		<tr><td>audio</td><td>Text max 50</td><td>The audio stream details (mono/stereo/etc.)</td></tr>
		<tr><td>boughtdate</td><td>Date</td><td>The date the movie was bought/added</td></tr>
	</tbody>
</table>

<h3>actors</h3>

<table>
	<thead><tr><th>Column</th><th>Type</th><th>Notes</th></tr></thead>
	<tbody>
		<tr><td>firstname</td><td>Text max 255</td><td>The actor's first name</td></tr>
		<tr><td>lastname</td><td>Text max 255</td><td>The actor's last name</td></tr>
		<tr><td>shortname</td><td>Text max 50</td><td>A short name used as a unique identifier</td></tr>
		<tr><td>nickname</td><td>Text max 255</td><td>A list of nicknames</td></tr>
		<tr><td>birthyear</td><td>Integer max 9999</td><td>Birth year of the actor (0 for unknown)</td></tr>
		<tr><td>deathyear</td><td>Integer max 9999</td><td>Death year of the actor (0 for unknown/none)</td></tr>
		<tr><td>gender</td><td>Integer max 1</td><td>1=female, 0=male</td></tr>
		<tr><td>picture</td><td>Text max 255</td><td>Path to local actor picture</td></tr>
		<tr><td>thumb</td><td>Text max 255</td><td>Path to local actor picture thumbnail</td></tr>
		<tr><td>bigpicture</td><td>Text max 255</td><td>Path to local actor large picture</td></tr>
		<tr><td>gallery</td><td>Text unlimited</td><td>Markup with links to galleries</td></tr>
		<tr><td>stats</td><td>Text unlimited</td><td>Markup with actor stats</td></tr>
		<tr><td>specialities</td><td>Text unlimited</td><td>Markup with list of specialities</td></tr>
		<tr><td>rating1</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating2</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating3</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating4</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating5</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating6</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating7</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating8</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating9</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating10</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating11</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating12</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating13</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating14</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating15</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>rating16</td><td>Integer max 9</td><td>Rating named in settings.php</td></tr>
		<tr><td>comments</td><td>Text unlimited</td><td>Markup with comments</td></tr>
	</tbody>
</table>

<h3>categories</h3>

<table>
	<thead><tr><th>Column</th><th>Type</th><th>Notes</th></tr></thead>
	<tbody>
		<tr><td>name</td><td>Text max 255</td><td>The category name</td></tr>
		<tr><td>shortname</td><td>Text max 50</td><td>A short name used as a unique identifier</td></tr>
		<tr><td>parent</td><td>Text max 50</td><td>The unique identifier of the parent category</td></tr>
	</tbody>
</table>

<h3>studios</h3>

<table>
	<thead><tr><th>Column</th><th>Type</th><th>Notes</th></tr></thead>
	<tbody>
		<tr><td>name</td><td>Text max 255</td><td>The studio name</td></tr>
		<tr><td>shortname</td><td>Text max 50</td><td>A short name used as a unique identifier</td></tr>
		<tr><td>specialities</td><td>Text unlimited</td><td>Markup with list of specialities</td></tr>
	</tbody>
</table>

<h3>directors</h3>

<table>
	<thead><tr><th>Column</th><th>Type</th><th>Notes</th></tr></thead>
	<tbody>
		<tr><td>name</td><td>Text max 255</td><td>The studio name</td></tr>
		<tr><td>shortname</td><td>Text max 50</td><td>A short name used as a unique identifier</td></tr>
		<tr><td>specialities</td><td>Text unlimited</td><td>Markup with list of specialities</td></tr>
		<tr><td>gender</td><td>Integer max 1</td><td>1=female, 0=male</td></tr>
	</tbody>
</table>

<h3>moviecat</h3>

<table>
	<thead><tr><th>Column</th><th>Type</th><th>Notes</th></tr></thead>
	<tbody>
		<tr><td>movie</td><td>Text max 50</td><td>Unique identifier of the movie</td></tr>
		<tr><td>category</td><td>Text max 50</td><td>Unique identifier of the category</td></tr>
		<tr><td>unqid</td><td>Integer max 99999</td><td>Automatic unique identifier</td></tr>
	</tbody>
</table>

<h3>movieact</h3>

<table>
	<thead><tr><th>Column</th><th>Type</th><th>Notes</th></tr></thead>
	<tbody>
		<tr><td>movie</td><td>Text max 50</td><td>Unique identifier of the movie</td></tr>
		<tr><td>actor</td><td>Text max 50</td><td>Unique identifier of the actor</td></tr>
		<tr><td>partsplayed</td><td>Text max 255</td><td>The character names played by the actor</td></tr>
		<tr><td>unqid</td><td>Integer max 99999</td><td>Automatic unique identifier</td></tr>
	</tbody>
</table>

<?php

/* template includes */
include('../../includes/contentend.php');
if( !$navfirst ) { getPageNav(); }
include('../../includes/bodyend.php');

?>